package dev.flyfish.framework.auditor;

import dev.flyfish.framework.domain.authorized.AuthorizedDomain;
import dev.flyfish.framework.domain.base.IUser;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.security.core.context.ReactiveSecurityContextHolder;
import org.springframework.stereotype.Component;
import reactor.core.publisher.Mono;

@Component
@RequiredArgsConstructor
public class ReactiveAuthorizeAuditor implements ReactiveBeanAuditor<AuthorizedDomain> {

    /**
     * 对实体进行审查，并补全相关字段
     *
     * @param data 原数据
     * @return 结果
     */
    @Override
    public Mono<AuthorizedDomain> audit(AuthorizedDomain data) {
        if (StringUtils.isBlank(data.getAuthorizeId())) {
            return ReactiveSecurityContextHolder.getContext()
                    .map(ctx -> (IUser) ctx.getAuthentication().getPrincipal())
                    .map(user -> {
                        data.setAuthorizeId(user.getAuthority());
                        return data;
                    })
                    .defaultIfEmpty(data);
        }
        return Mono.just(data);
    }
}
