package dev.flyfish.framework.auditor;

import dev.flyfish.framework.domain.base.Domain;
import dev.flyfish.framework.generation.code.CodeRules;
import dev.flyfish.framework.generation.property.Generations;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;
import reactor.core.publisher.Mono;

import java.util.ArrayList;
import java.util.List;

/**
 * 异步公共审查
 *
 * @author wangyu
 */
@Component
@RequiredArgsConstructor
public class ReactiveCommonBeanAuditor implements ReactiveBeanAuditor<Domain> {

    /**
     * 对实体进行审查，并补全相关字段
     *
     * @param data 原数据
     * @return 结果
     */
    @Override
    public Mono<Domain> audit(Domain data) {
        List<Mono<Domain>> signals = new ArrayList<>();
        // 编码审查，自动生成，仅在初次保存时生成
        if (StringUtils.isBlank(data.getId())) {
            // 生成字段值
            Generations.apply(data);
            // 生成编码
            if (StringUtils.isBlank(data.getCode())) {
                Mono<Domain> setCode = CodeRules.retrieve(data)
                        .map(code -> {
                            data.setCode(code);
                            return data;
                        })
                        .thenReturn(data);
                signals.add(setCode);
            }
        }
        return Mono.zip(signals, results -> data).defaultIfEmpty(data);
    }
}
