package dev.flyfish.framework.config;

import dev.flyfish.framework.bean.EnumValue;
import dev.flyfish.framework.enums.NamedEnum;
import dev.flyfish.framework.utils.ClassPathResourceScanner;
import dev.flyfish.framework.utils.StringFormats;
import org.apache.commons.lang3.ClassUtils;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.context.annotation.ImportBeanDefinitionRegistrar;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 枚举相关，专门处理枚举
 *
 * @author wangyu
 */
public class EnumConfig implements InitializingBean, ImportBeanDefinitionRegistrar {

    // 映射管理，避免class.forName扫描包路径
    private final Map<String, Map<String, String>> mapper = new HashMap<>();

    private final Map<String, List<EnumValue>> values = new HashMap<>();

    public EnumConfig() {
        // 得到枚举类
        ClassPathResourceScanner.forSuperType(NamedEnum.class)
                .scan("dev.flyfish.project")
                .filter(clazz -> ClassUtils.isAssignable(clazz, Enum.class))
                .forEach(clazz -> {
                    String name = StringFormats.camel2Line(clazz.getSimpleName());
                    List<EnumValue> values = Arrays.stream(clazz.getEnumConstants()).reduce(new ArrayList<>(), (result, item) -> {
                        result.add(new EnumValue(((Enum<?>) item).name(), ((NamedEnum) item).getName()));
                        return result;
                    }, (a, b) -> a);
                    this.mapper.put(name, values.stream().collect(Collectors.toMap(EnumValue::getValue, EnumValue::getText)));
                    this.values.put(name, values);
                });
    }

    @Override
    public void afterPropertiesSet() throws Exception {

    }
}
