package dev.flyfish.framework.config.encrypt;

import dev.flyfish.framework.utils.HexUtils;
import com.ulisesbocchio.jasyptspringboot.EncryptablePropertyResolver;
import org.apache.commons.lang3.StringUtils;
import org.jasypt.util.binary.AES256BinaryEncryptor;

import java.nio.charset.StandardCharsets;

/**
 * 加密处理器
 *
 * @author wangyu
 */
public class AESEncryptablePropertyResolver implements EncryptablePropertyResolver {

    private static final String PREFIX = "$-";
    private final AES256BinaryEncryptor encryptor;

    public AESEncryptablePropertyResolver(String password) {
        this.encryptor = new AES256BinaryEncryptor();
        encryptor.setPassword(password);
    }

    public String encrypt(String password) {
        byte[] bytes = password.getBytes(StandardCharsets.UTF_8);
        return PREFIX + HexUtils.byteArray2Hex(encryptor.encrypt(bytes));
    }

    @Override
    public String resolvePropertyValue(String value) {
        if (StringUtils.isNotBlank(value) && value.startsWith(PREFIX)) {
            String encrypted = StringUtils.substringAfter(value, PREFIX);
            byte[] bytes = encryptor.decrypt(HexUtils.hex2ByteArray(encrypted));
            return new String(bytes, StandardCharsets.UTF_8);
        }
        return value;
    }

    public static void main(String[] args) {
        String test = "$-dcfe1dbfdf51e1b007c68c6c0b7008c774ed7c05d8aca2797562159ac1098bcc5a9fdcb42e6acb6562944c21969d34a2";
        AESEncryptablePropertyResolver resolver = new AESEncryptablePropertyResolver("sxu-service-2020");
        String value = resolver.resolvePropertyValue(test);
        System.out.println(value);
    }
}
