package dev.flyfish.framework.mongodb.query.adaptor;

import dev.flyfish.framework.mongodb.utils.CriteriaUtils;
import dev.flyfish.framework.query.Queries;
import dev.flyfish.framework.query.spi.adaptor.CriteriaAdaptor;
import org.bson.types.ObjectId;
import org.springframework.data.mongodb.core.query.Criteria;

import java.util.Collection;
import java.util.List;

public class MongoCriteriaAdaptor implements CriteriaAdaptor<Criteria> {

    @Override
    public boolean isEmpty(Criteria criteria) {
        return CriteriaUtils.isEmpty(criteria);
    }

    @Override
    public Criteria empty() {
        return new Criteria();
    }

    @Override
    public Criteria and(Criteria first, Criteria other) {
        return first.andOperator(other);
    }

    @Override
    public Criteria or(Criteria first, Criteria other) {
        return first.orOperator(other);
    }

    @Override
    public Criteria eq(String column, Object value) {
        return Criteria.where(column).is(value);
    }

    @Override
    public Criteria hasId(String column, Object value) {
        return Criteria.where(column + ".$id").is(new ObjectId(String.valueOf(value)));
    }

    @Override
    public Criteria has(String column, Object value) {
        return Criteria.where(column).is(value);
    }

    @Override
    public Criteria ne(String column, Object value) {
        return Criteria.where(column).ne(value);
    }

    @Override
    public Criteria between(String column, List<?> items) {
        return Criteria.where(column).gte(items.get(0)).lte(items.get(1));
    }

    @Override
    public Criteria like(String column, String keyword, Queries.Direction direction) {
        // 匹配开头
        if (direction == Queries.Direction.LEFT) {
            keyword = "^" + keyword;
        } else if (direction == Queries.Direction.RIGHT) {
            keyword = keyword + "$";
        }
        return Criteria.where(column).regex(keyword);
    }

    @Override
    public Criteria isNull(String column) {
        return Criteria.where(column).isNull();
    }

    @Override
    public Criteria lt(String column, Object value) {
        return Criteria.where(column).lt(value);
    }

    @Override
    public Criteria lte(String column, Object value) {
        return Criteria.where(column).lte(value);
    }

    @Override
    public Criteria gt(String column, Object value) {
        return Criteria.where(column).gt(value);
    }

    @Override
    public Criteria gte(String column, Object value) {
        return Criteria.where(column).gte(value);
    }

    @Override
    public Criteria in(String column, Collection<?> values) {
        return Criteria.where(column).in(values);
    }

    @Override
    public Criteria in(String column, Object... values) {
        return Criteria.where(column).in(values);
    }

    @Override
    public Criteria nin(String column, Object... values) {
        return Criteria.where(column).nin(values);
    }

    @Override
    public Criteria nin(String column, Collection<?> values) {
        return Criteria.where(column).nin(values);
    }
}
