package dev.flyfish.framework.r2dbc.metadata;

import dev.flyfish.framework.annotations.Property;
import dev.flyfish.framework.r2dbc.metadata.reference.R2dbcAssociation;
import dev.flyfish.framework.r2dbc.metadata.reference.R2dbcCollection;
import dev.flyfish.framework.r2dbc.metadata.reference.R2dbcRelation;
import dev.flyfish.framework.r2dbc.metadata.reference.field.FieldAccessor;
import dev.flyfish.framework.relational.mapping.Association;
import lombok.Data;
import org.springframework.data.mapping.PersistentEntity;
import org.springframework.data.mapping.PersistentProperty;
import org.springframework.data.relational.core.sql.Visitable;

import java.util.ArrayList;
import java.util.List;

/**
 * 表元数据
 *
 * @author wangyu
 */
@Data
@Property("表的元数据，用于关联查询")
public class R2dbcTableMetadata implements Visitable {

    @Property("表实体信息")
    private PersistentEntity<?, ?> entity;

    @Property("一对一关联信息")
    private List<R2dbcAssociation> associations = new ArrayList<>();

    @Property("一对多关联信息")
    private List<R2dbcCollection> collections = new ArrayList<>();

    @Property("多对多关联信息")
    private List<R2dbcRelation> relations = new ArrayList<>();

    public R2dbcTableMetadata(PersistentEntity<?, ?> entity) {
        this.entity = entity;
    }

    public void addAssociation(PersistentEntity<?, ?> entity, PersistentProperty<?> property, FieldAccessor accessor, boolean inner) {
        this.associations.add(R2dbcAssociation.of(entity, property, accessor, inner));
    }

    public void addCollection(PersistentEntity<?, ?> entity, PersistentProperty<?> property, FieldAccessor accessor) {
        this.collections.add(R2dbcCollection.of(entity, property, accessor));
    }

    public void addRelation(PersistentEntity<?, ?> entity, Association association, FieldAccessor accessor) {
        this.relations.add(R2dbcRelation.of(entity, association, accessor));
    }

    public boolean hasAssociation() {
        return !associations.isEmpty() || !collections.isEmpty() || !relations.isEmpty();
    }
}
