package org.springframework.data.relational.core.sql;

import lombok.Getter;
import org.springframework.data.relational.core.sql.render.FunctionVisitor;
import org.springframework.data.relational.core.sql.render.RenderContext;
import org.springframework.util.Assert;

import java.util.Arrays;
import java.util.List;

/**
 * 可以渲染函数的条件
 *
 * @author wangyu
 */
public class FunctionCondition extends ConstantCondition implements Condition {

    @Getter
    private final RenderContext renderContext;

    @Getter
    private final SimpleFunction function;

    private final StringBuilder builder = new StringBuilder();

    private FunctionCondition(RenderContext context, SimpleFunction function) {
        super("");
        this.renderContext = context;
        this.function = function;
    }

    public static Condition of(RenderContext context, String functionName, List<Expression> args) {
        return new FunctionCondition(context, SimpleFunction.create(functionName, args));
    }

    public static Condition of(RenderContext context, String functionName, Expression... args) {
        return of(context, functionName, Arrays.asList(args));
    }

    @Override
    public void visit(Visitor visitor) {
        Assert.notNull(visitor, "Visitor must not be null");

        visitor.enter(this);
        function.visit(visitor);
        visitor.leave(this);
    }

    @Override
    public String toString() {
        FunctionVisitor visitor = new FunctionVisitor(this,  builder::append);
        this.visit(visitor);
        return builder.toString();
    }
}
