package dev.flyfish.framework.beans.meta.parser.chain.impl;

import dev.flyfish.framework.beans.meta.parser.BeanPropertyAnnotations;
import dev.flyfish.framework.beans.meta.parser.chain.BeanPropertyAnnotationChain;
import org.springframework.data.util.CastUtils;

import java.lang.annotation.Annotation;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.function.Supplier;

/**
 * 单例的，空实现
 *
 * @param <A> 注解泛型
 * @param <T> 实际泛型
 */
public class EmptyAnnotationChain<A extends Annotation, T> extends BasicAnnotationChainSupport
        implements BeanPropertyAnnotationChain<A, T> {

    public EmptyAnnotationChain(BeanPropertyAnnotations parent) {
        super(parent);
    }

    /**
     * 映射转换
     *
     * @param mapper 映射器
     * @return 结果
     */
    @Override
    public <R> BeanPropertyAnnotationChain<A, R> map(Function<T, R> mapper) {
        return CastUtils.cast(this);
    }

    /**
     * 过滤，不满足的将直接empty
     *
     * @param filter 过滤器
     * @return 结果
     */
    @Override
    public BeanPropertyAnnotationChain<A, T> filter(Predicate<T> filter) {
        return this;
    }

    /**
     * 过滤，不满足的将直接empty
     *
     * @param filter 过滤器
     * @return 结果
     */
    @Override
    public BeanPropertyAnnotationChain<A, T> filter(Supplier<Boolean> filter) {
        return this;
    }

    /**
     * 如果存在，则做
     *
     * @param consumer 消费者
     * @return 结果
     */
    @Override
    public BeanPropertyAnnotationChain<A, T> then(Consumer<T> consumer) {
        return this;
    }

    /**
     * 存在时执行逻辑，不需要结果
     *
     * @param handler 处理器
     * @return 结果
     */
    @Override
    public BeanPropertyAnnotationChain<A, T> exists(Runnable handler) {
        return this;
    }

    /**
     * 不存在做的事情
     *
     * @param fallback 补偿逻辑
     * @return 结果
     */
    @Override
    public BeanPropertyAnnotationChain<A, T> empty(Runnable fallback) {
        if (!parent.last()) {
            fallback.run();
        }
        return this;
    }

    /**
     * 直接获取结果
     *
     * @return 结果
     */
    @Override
    public A synthesize() {
        return null;
    }
}
