package dev.flyfish.framework.utils;

import org.apache.commons.lang3.StringUtils;
import org.springframework.web.reactive.function.server.ServerRequest;

import java.net.InetSocketAddress;
import java.util.Optional;

public class ClientUtil {
    /**
     * 获取客户端真实ip
     *
     * @param request
     * @return
     */
    public static String getClientIp(ServerRequest request) {
        Optional<String> optional = filteredIp(request, "x-forwarded-for");
        if (optional.isPresent()) {
            return optional.get();
        }
        optional = filteredIp(request, "Proxy-Client-IP");
        if (optional.isPresent()) {
            return optional.get();
        }
        optional = filteredIp(request, "WL-Proxy-Client-IP");
        return optional
                .orElseGet(() -> request.remoteAddress().map(InetSocketAddress::getHostName)
                        .orElse(null)
                );
    }

    private static Optional<String> filteredIp(ServerRequest request, String header) {
        return request.headers().header(header).stream()
                .filter(ip -> StringUtils.isNotBlank(ip) && !"unknown".equals(ip)).findFirst();
    }
}
